pub unsafe extern "C" fn chewing_delete(ctx: *mut ChewingContext)Expand description
@brief Release the handle and internal memory by given Chewing instance @see chewing_new()
@param ctx Chewing IM context
pub unsafe extern "C" fn chewing_delete(ctx: *mut ChewingContext)@brief Release the handle and internal memory by given Chewing instance @see chewing_new()
@param ctx Chewing IM context