pub unsafe extern "C" fn chewing_get_KBType(
ctx: *const ChewingContext,
) -> c_intExpand description
@brief Get keyboard mapping type
@param ctx @return If successed then return keyboard mapping type from KBStr2Num
pub unsafe extern "C" fn chewing_get_KBType(
ctx: *const ChewingContext,
) -> c_int@brief Get keyboard mapping type
@param ctx @return If successed then return keyboard mapping type from KBStr2Num